/*  This file was created by Configure. Any change made to it will be lost
 *  next time Configure is run.
 */
#ifndef __CONFIG_H__
#define __CONFIG_H__
#define UNIX
#define GPHELP "/usr/local/bin/gphelp"
#define GPDATADIR "/usr/local/share/pari"
#define GPMISCDIR "/usr/local/share/pari"
#define SHELL_Q '\''

#define PARIVERSION "GP/PARI CALCULATOR Version 2.1.7 (released)"
#ifdef __cplusplus
# define PARIINFO "C++ armv7 (C portable kernel) 32-bit version"
#else
# define PARIINFO "armv7 (C portable kernel) 32-bit version"
#endif
#define PARI_VERSION_CODE 131335
#define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))

#define PARI_DOUBLE_FORMAT 1
#define __HAS_NO_ASM__
#define ASMINLINE

/*  Location of GNU gzip program (enables reading of .Z and .gz files). */
#define GNUZCAT
#define ZCAT "/usr/bin/gzip -dc"

/*  Use GNU readline library
 *  This is incompatible with SUN commandtools (not with shelltools).
 */
#define READLINE "4.3"
#define HAS_COMPLETION_APPEND_CHAR
#define HAS_RL_GENERIC_BIND
#define HAS_RL_SAVE_PROMPT
#define HAS_RL_MESSAGE
#define HAS_RL_COMPLETION_MATCHES
#define HAS_RL_COMPLETION_FUNC_T

#define NOEXP2
#define USE_GETRUSAGE 1
#define USE_SIGSETMASK 1
#define HAS_DLOPEN
#define DL_DFLT_NAME "libpari."
#define STACK_CHECK
#define HAS_TIOCGWINSZ
#define HAS_STRFTIME
#define HAS_OPENDIR
#endif
